use Bio::mGen;

$|=1;

my $as="NZ_AAAG02000001.1",$gn="Rrub02000030";

#mGen::reload_gene($as);

#print mGen::get_set();
print mGen::get_desc($as);
#print mGen::get_fasta($as);
#print mGen::get_list($as);
#print mGen::get_genes($as,$gn);
#print mGen::get_list($as,$gn);

#print mGen::get_genes($as);
